# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel


class HasAlphaChannelMatch(UniversalBaseModel):
    """
    The result's alpha channel presence is a match for the search query
    """

    has_alpha_channel: bool = pydantic.Field()
    """
    Whether the result has an alpha channel
    """

    type: typing.Literal["has_alpha_channel_match"] = "has_alpha_channel_match"

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel


class NameMatch(UniversalBaseModel):
    """
    The result's name is a match for the search query
    """

    name: str = pydantic.Field()
    """
    The name of the result
    """

    terms: typing.List[str] = pydantic.Field()
    """
    The terms in the search query that matched the result's name
    """

    type: typing.Literal["name_match"] = "name_match"

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.action_create_response import ActionCreateResponse
from ..types.action_response import ActionResponse
from ..types.action_with_includes_response import ActionWithIncludesResponse
from ..types.actions_with_includes_response import ActionsWithIncludesResponse
from ..types.include_total_count import IncludeTotalCount
from ..types.request_after_opaque_cursor import RequestAfterOpaqueCursor
from ..types.request_page_size import RequestPageSize
from ..types.uuid_ import Uuid
from .raw_client import AsyncRawCustomActionsClient, RawCustomActionsClient
from .types.action_create_params_data import ActionCreateParamsData
from .types.action_update_params_data import ActionUpdateParamsData

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class CustomActionsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawCustomActionsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawCustomActionsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawCustomActionsClient
        """
        return self._raw_client

    def actions_show(
        self,
        account_id: Uuid,
        action_id: Uuid,
        *,
        include: typing.Optional[typing.Literal["creator"]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ActionWithIncludesResponse:
        """
        Show custom action details. <br/>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        action_id : Uuid


        include : typing.Optional[typing.Literal["creator"]]


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ActionWithIncludesResponse
            OK

        Examples
        --------
        from frameio_experimental import FrameioExperimental

        client = FrameioExperimental(
            api_version="YOUR_API_VERSION",
            token="YOUR_TOKEN",
        )
        client.custom_actions.actions_show(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            action_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
        )
        """
        _response = self._raw_client.actions_show(
            account_id, action_id, include=include, request_options=request_options
        )
        return _response.data

    def actions_delete(
        self, account_id: Uuid, action_id: Uuid, *, request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        Delete a custom action. <br/>Rate Limits: 60 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        action_id : Uuid


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        from frameio_experimental import FrameioExperimental

        client = FrameioExperimental(
            api_version="YOUR_API_VERSION",
            token="YOUR_TOKEN",
        )
        client.custom_actions.actions_delete(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            action_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
        )
        """
        _response = self._raw_client.actions_delete(account_id, action_id, request_options=request_options)
        return _response.data

    def actions_update(
        self,
        account_id: Uuid,
        action_id: Uuid,
        *,
        data: ActionUpdateParamsData,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ActionResponse:
        """
        Update custom action details. <br/>Rate Limits: 10 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        action_id : Uuid


        data : ActionUpdateParamsData

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ActionResponse
            OK

        Examples
        --------
        from frameio_experimental import FrameioExperimental
        from frameio_experimental.custom_actions import ActionUpdateParamsData

        client = FrameioExperimental(
            api_version="YOUR_API_VERSION",
            token="YOUR_TOKEN",
        )
        client.custom_actions.actions_update(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            action_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            data=ActionUpdateParamsData(
                active=True,
                description="customizing our workflow",
                event="my.event",
                multi_asset=True,
                name="First Custom Action",
                timeout=7,
                url="https://example.com/custom-action",
            ),
        )
        """
        _response = self._raw_client.actions_update(account_id, action_id, data=data, request_options=request_options)
        return _response.data

    def actions_index(
        self,
        account_id: Uuid,
        workspace_id: Uuid,
        *,
        include: typing.Optional[typing.Literal["creator"]] = None,
        after: typing.Optional[RequestAfterOpaqueCursor] = None,
        page_size: typing.Optional[RequestPageSize] = None,
        include_total_count: typing.Optional[IncludeTotalCount] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ActionsWithIncludesResponse:
        """
        List actions in a given workspace. <br/>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        workspace_id : Uuid


        include : typing.Optional[typing.Literal["creator"]]


        after : typing.Optional[RequestAfterOpaqueCursor]
            Opaque Cursor query param for requests returning paginated results.
            <br/>
            NOTE: this value is auto-generated and included as part of links from a previous response. It is not intended to be human readable.

        page_size : typing.Optional[RequestPageSize]


        include_total_count : typing.Optional[IncludeTotalCount]


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ActionsWithIncludesResponse
            OK

        Examples
        --------
        from frameio_experimental import FrameioExperimental

        client = FrameioExperimental(
            api_version="YOUR_API_VERSION",
            token="YOUR_TOKEN",
        )
        client.custom_actions.actions_index(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            workspace_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            after="<opaque_cursor>",
            page_size=10,
            include_total_count=False,
        )
        """
        _response = self._raw_client.actions_index(
            account_id,
            workspace_id,
            include=include,
            after=after,
            page_size=page_size,
            include_total_count=include_total_count,
            request_options=request_options,
        )
        return _response.data

    def actions_create(
        self,
        account_id: Uuid,
        workspace_id: Uuid,
        *,
        data: ActionCreateParamsData,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ActionCreateResponse:
        """
        Create a custom action in a workspace. <br/>Rate Limits: 10 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        workspace_id : Uuid


        data : ActionCreateParamsData

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ActionCreateResponse
            Created

        Examples
        --------
        from frameio_experimental import FrameioExperimental
        from frameio_experimental.custom_actions import ActionCreateParamsData

        client = FrameioExperimental(
            api_version="YOUR_API_VERSION",
            token="YOUR_TOKEN",
        )
        client.custom_actions.actions_create(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            workspace_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            data=ActionCreateParamsData(
                description="customizing our workflow",
                event="my.event",
                name="First Custom Action",
                timeout=7,
                url="https://example.com/custom-action",
            ),
        )
        """
        _response = self._raw_client.actions_create(
            account_id, workspace_id, data=data, request_options=request_options
        )
        return _response.data


class AsyncCustomActionsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawCustomActionsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawCustomActionsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawCustomActionsClient
        """
        return self._raw_client

    async def actions_show(
        self,
        account_id: Uuid,
        action_id: Uuid,
        *,
        include: typing.Optional[typing.Literal["creator"]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ActionWithIncludesResponse:
        """
        Show custom action details. <br/>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        action_id : Uuid


        include : typing.Optional[typing.Literal["creator"]]


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ActionWithIncludesResponse
            OK

        Examples
        --------
        import asyncio

        from frameio_experimental import AsyncFrameioExperimental

        client = AsyncFrameioExperimental(
            api_version="YOUR_API_VERSION",
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.custom_actions.actions_show(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                action_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.actions_show(
            account_id, action_id, include=include, request_options=request_options
        )
        return _response.data

    async def actions_delete(
        self, account_id: Uuid, action_id: Uuid, *, request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        Delete a custom action. <br/>Rate Limits: 60 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        action_id : Uuid


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import asyncio

        from frameio_experimental import AsyncFrameioExperimental

        client = AsyncFrameioExperimental(
            api_version="YOUR_API_VERSION",
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.custom_actions.actions_delete(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                action_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.actions_delete(account_id, action_id, request_options=request_options)
        return _response.data

    async def actions_update(
        self,
        account_id: Uuid,
        action_id: Uuid,
        *,
        data: ActionUpdateParamsData,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ActionResponse:
        """
        Update custom action details. <br/>Rate Limits: 10 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        action_id : Uuid


        data : ActionUpdateParamsData

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ActionResponse
            OK

        Examples
        --------
        import asyncio

        from frameio_experimental import AsyncFrameioExperimental
        from frameio_experimental.custom_actions import ActionUpdateParamsData

        client = AsyncFrameioExperimental(
            api_version="YOUR_API_VERSION",
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.custom_actions.actions_update(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                action_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                data=ActionUpdateParamsData(
                    active=True,
                    description="customizing our workflow",
                    event="my.event",
                    multi_asset=True,
                    name="First Custom Action",
                    timeout=7,
                    url="https://example.com/custom-action",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.actions_update(
            account_id, action_id, data=data, request_options=request_options
        )
        return _response.data

    async def actions_index(
        self,
        account_id: Uuid,
        workspace_id: Uuid,
        *,
        include: typing.Optional[typing.Literal["creator"]] = None,
        after: typing.Optional[RequestAfterOpaqueCursor] = None,
        page_size: typing.Optional[RequestPageSize] = None,
        include_total_count: typing.Optional[IncludeTotalCount] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ActionsWithIncludesResponse:
        """
        List actions in a given workspace. <br/>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        workspace_id : Uuid


        include : typing.Optional[typing.Literal["creator"]]


        after : typing.Optional[RequestAfterOpaqueCursor]
            Opaque Cursor query param for requests returning paginated results.
            <br/>
            NOTE: this value is auto-generated and included as part of links from a previous response. It is not intended to be human readable.

        page_size : typing.Optional[RequestPageSize]


        include_total_count : typing.Optional[IncludeTotalCount]


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ActionsWithIncludesResponse
            OK

        Examples
        --------
        import asyncio

        from frameio_experimental import AsyncFrameioExperimental

        client = AsyncFrameioExperimental(
            api_version="YOUR_API_VERSION",
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.custom_actions.actions_index(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                workspace_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                after="<opaque_cursor>",
                page_size=10,
                include_total_count=False,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.actions_index(
            account_id,
            workspace_id,
            include=include,
            after=after,
            page_size=page_size,
            include_total_count=include_total_count,
            request_options=request_options,
        )
        return _response.data

    async def actions_create(
        self,
        account_id: Uuid,
        workspace_id: Uuid,
        *,
        data: ActionCreateParamsData,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ActionCreateResponse:
        """
        Create a custom action in a workspace. <br/>Rate Limits: 10 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        workspace_id : Uuid


        data : ActionCreateParamsData

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ActionCreateResponse
            Created

        Examples
        --------
        import asyncio

        from frameio_experimental import AsyncFrameioExperimental
        from frameio_experimental.custom_actions import ActionCreateParamsData

        client = AsyncFrameioExperimental(
            api_version="YOUR_API_VERSION",
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.custom_actions.actions_create(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                workspace_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                data=ActionCreateParamsData(
                    description="customizing our workflow",
                    event="my.event",
                    name="First Custom Action",
                    timeout=7,
                    url="https://example.com/custom-action",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.actions_create(
            account_id, workspace_id, data=data, request_options=request_options
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel


class KeywordsMatch(UniversalBaseModel):
    """
    The result's keywords are a match for the search query
    """

    keywords: typing.List[str] = pydantic.Field()
    """
    The keywords of the result that are relevant to the search
    """

    type: typing.Literal["keywords_match"] = "keywords_match"

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

from .assignee_match import AssigneeMatch
from .audio_sample_rate_match import AudioSampleRateMatch
from .bit_depth_match import BitDepthMatch
from .bit_rate_match import BitRateMatch
from .channels_match import ChannelsMatch
from .codec_match import CodecMatch
from .color_space_match import ColorSpaceMatch
from .comment_count_match import CommentCountMatch
from .comment_match import CommentMatch
from .creator_match import CreatorMatch
from .deleted_at_match import DeletedAtMatch
from .duration_match import DurationMatch
from .dynamic_range_match import DynamicRangeMatch
from .file_type_match import FileTypeMatch
from .filesize_match import FilesizeMatch
from .format_match import FormatMatch
from .frame_rate_match import FrameRateMatch
from .has_alpha_channel_match import HasAlphaChannelMatch
from .inserted_at_match import InsertedAtMatch
from .keywords_match import KeywordsMatch
from .name_match import NameMatch
from .notes_match import NotesMatch
from .page_count_match import PageCountMatch
from .project_match import ProjectMatch
from .rating_match import RatingMatch
from .resolution_height_match import ResolutionHeightMatch
from .resolution_width_match import ResolutionWidthMatch
from .source_filename_match import SourceFilenameMatch
from .status_match import StatusMatch
from .transcription_match import TranscriptionMatch
from .updated_at_match import UpdatedAtMatch
from .uploaded_at_match import UploadedAtMatch
from .visual_match import VisualMatch

SearchMatch = typing.Union[
    NameMatch,
    SourceFilenameMatch,
    ProjectMatch,
    CreatorMatch,
    AssigneeMatch,
    FormatMatch,
    KeywordsMatch,
    StatusMatch,
    VisualMatch,
    TranscriptionMatch,
    CommentMatch,
    RatingMatch,
    CommentCountMatch,
    PageCountMatch,
    DurationMatch,
    FilesizeMatch,
    AudioSampleRateMatch,
    NotesMatch,
    UploadedAtMatch,
    UpdatedAtMatch,
    DeletedAtMatch,
    InsertedAtMatch,
    FileTypeMatch,
    BitDepthMatch,
    BitRateMatch,
    CodecMatch,
    ChannelsMatch,
    FrameRateMatch,
    HasAlphaChannelMatch,
    ColorSpaceMatch,
    ResolutionWidthMatch,
    ResolutionHeightMatch,
    DynamicRangeMatch,
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel


class ScrubSheetMediaLinkMetadata(UniversalBaseModel):
    """
    Metadata for the scrub sheet.<br>Metadata is only available for video assets.
    """

    frames: typing.Optional[int] = pydantic.Field(default=None)
    """
    Number of frames represented in the scrub sheet.
    """

    padding: typing.Optional[int] = pydantic.Field(default=None)
    """
    Padding in pixels between thumbnails.
    """

    thumb_height: typing.Optional[int] = pydantic.Field(default=None)
    """
    Thumbnail height in pixels.
    """

    thumb_width: typing.Optional[int] = pydantic.Field(default=None)
    """
    Thumbnail width in pixels.
    """

    tile_x: typing.Optional[int] = pydantic.Field(default=None)
    """
    Horizontal tile index (zero-based).
    """

    tile_y: typing.Optional[int] = pydantic.Field(default=None)
    """
    Vertical tile index (zero-based).
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

from .asset_search_result import AssetSearchResult
from .project_search_result import ProjectSearchResult

SearchResponseDataItem = typing.Union[AssetSearchResult, ProjectSearchResult]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from .rendition_media_link import RenditionMediaLink
from .scrub_sheet_media_link_metadata import ScrubSheetMediaLinkMetadata


class ScrubSheetMediaLink(RenditionMediaLink):
    metadata: typing.Optional[ScrubSheetMediaLinkMetadata] = pydantic.Field(default=None)
    """
    Metadata for the scrub sheet.<br>Metadata is only available for video assets.
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel


class TranscriptionMatchMatchesItem(UniversalBaseModel):
    """
    A transcription segment that is a match for the search query
    """

    id: str = pydantic.Field()
    """
    Transcription segment ID
    """

    snippets: typing.List[str] = pydantic.Field()
    """
    The small portion of the transcription that is a match for the search query
    """

    terms: typing.List[str] = pydantic.Field()
    """
    The terms in the search query that are a match for the result's transcription
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel
from .update_user_roles_response_data import UpdateUserRolesResponseData


class UpdateUserRolesResponse(UniversalBaseModel):
    data: UpdateUserRolesResponseData

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel


class FrameRateMatch(UniversalBaseModel):
    """
    The result's frame rate is a match for the search query
    """

    frame_rate: float = pydantic.Field()
    """
    The frame rate of the result in fps
    """

    type: typing.Literal["frame_rate_match"] = "frame_rate_match"

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel
from .account_user_role import AccountUserRole
from .links import Links


class AccountUserRolesResponse(UniversalBaseModel):
    """
    Frame.io Account user role details
    """

    data: typing.List[AccountUserRole] = pydantic.Field()
    """
    Account User Roles
    """

    links: Links
    total_count: typing.Optional[int] = pydantic.Field(default=None)
    """
    Total count
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

SyncGroupWithIncludesSyncStatus = typing.Union[
    typing.Literal["not_started", "in_progress", "completed", "error"], typing.Any
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel
from .user_single_definition_params_field_configuration import UserSingleDefinitionParamsFieldConfiguration


class UserSingleDefinitionParams(UniversalBaseModel):
    field_configuration: UserSingleDefinitionParamsFieldConfiguration
    field_type: typing.Literal["user_single"] = "user_single"
    name: str = pydantic.Field()
    """
    Field definition name
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .account import Account
    from .account_role_data import AccountRoleData
    from .account_role_data_role import AccountRoleDataRole
    from .account_roles_item import AccountRolesItem
    from .account_sort import AccountSort
    from .account_user_role import AccountUserRole
    from .account_user_role_role import AccountUserRoleRole
    from .account_user_roles_response import AccountUserRolesResponse
    from .account_user_sort import AccountUserSort
    from .accounts_response import AccountsResponse
    from .action import Action
    from .action_create_response import ActionCreateResponse
    from .action_create_response_data import ActionCreateResponseData
    from .action_response import ActionResponse
    from .action_with_includes import ActionWithIncludes
    from .action_with_includes_response import ActionWithIncludesResponse
    from .actions_with_includes_response import ActionsWithIncludesResponse
    from .anchor import Anchor
    from .asset import Asset
    from .asset_common import AssetCommon
    from .asset_common_type import AssetCommonType
    from .asset_common_with_includes import AssetCommonWithIncludes
    from .asset_common_with_includes_type import AssetCommonWithIncludesType
    from .asset_include import AssetInclude
    from .asset_search_result import AssetSearchResult
    from .asset_search_result_type import AssetSearchResultType
    from .asset_with_includes import AssetWithIncludes
    from .assignee_match import AssigneeMatch
    from .attachment_input import AttachmentInput
    from .audio_sample_rate_match import AudioSampleRateMatch
    from .audit_logs_include import AuditLogsInclude
    from .audit_logs_with_includes_response import AuditLogsWithIncludesResponse
    from .audit_logwith_includes import AuditLogwithIncludes
    from .audit_logwith_includes_event_type import AuditLogwithIncludesEventType
    from .audit_logwith_includes_resource_type import AuditLogwithIncludesResourceType
    from .bad_request import BadRequest
    from .bad_request_errors_item import BadRequestErrorsItem
    from .bad_request_errors_item_source import BadRequestErrorsItemSource
    from .bit_depth_match import BitDepthMatch
    from .bit_rate_match import BitRateMatch
    from .boolean_value import BooleanValue
    from .channels_match import ChannelsMatch
    from .children_type import ChildrenType
    from .codec_match import CodecMatch
    from .collection import Collection
    from .collection_aggregation_mode import CollectionAggregationMode
    from .collection_include import CollectionInclude
    from .collection_response import CollectionResponse
    from .collections_response import CollectionsResponse
    from .color_space_match import ColorSpaceMatch
    from .comment import Comment
    from .comment_attachment import CommentAttachment
    from .comment_attachment_response import CommentAttachmentResponse
    from .comment_count_match import CommentCountMatch
    from .comment_include import CommentInclude
    from .comment_match import CommentMatch
    from .comment_response import CommentResponse
    from .comment_sort import CommentSort
    from .comment_with_includes import CommentWithIncludes
    from .comment_with_includes_response import CommentWithIncludesResponse
    from .comments_with_includes_response import CommentsWithIncludesResponse
    from .conflict import Conflict
    from .conflict_errors_item import ConflictErrorsItem
    from .conflict_errors_item_source import ConflictErrorsItemSource
    from .creator_match import CreatorMatch
    from .date_definition import DateDefinition
    from .date_definition_field_configuration import DateDefinitionFieldConfiguration
    from .date_definition_field_configuration_display_format import DateDefinitionFieldConfigurationDisplayFormat
    from .date_definition_field_configuration_time_format import DateDefinitionFieldConfigurationTimeFormat
    from .date_definition_params import DateDefinitionParams
    from .date_definition_params_field_configuration import DateDefinitionParamsFieldConfiguration
    from .date_definition_params_field_configuration_display_format import (
        DateDefinitionParamsFieldConfigurationDisplayFormat,
    )
    from .date_definition_params_field_configuration_time_format import DateDefinitionParamsFieldConfigurationTimeFormat
    from .date_definition_with_includes import DateDefinitionWithIncludes
    from .date_value import DateValue
    from .deleted_at_match import DeletedAtMatch
    from .duration_match import DurationMatch
    from .dynamic_range_match import DynamicRangeMatch
    from .field_definition import FieldDefinition
    from .field_definition_include import FieldDefinitionInclude
    from .field_definition_response import FieldDefinitionResponse
    from .field_definition_sort import FieldDefinitionSort
    from .field_definition_with_includes import FieldDefinitionWithIncludes
    from .field_definitions_with_includes_response import FieldDefinitionsWithIncludesResponse
    from .field_value_common import FieldValueCommon
    from .field_value_common_field_type import FieldValueCommonFieldType
    from .file import File
    from .file_assets_with_includes_response import FileAssetsWithIncludesResponse
    from .file_remote_upload_response import FileRemoteUploadResponse
    from .file_response import FileResponse
    from .file_sort import FileSort
    from .file_status import FileStatus
    from .file_type_match import FileTypeMatch
    from .file_upload_status import FileUploadStatus
    from .file_upload_status_response import FileUploadStatusResponse
    from .file_with_includes import FileWithIncludes
    from .file_with_includes_response import FileWithIncludesResponse
    from .file_with_includes_status import FileWithIncludesStatus
    from .file_with_media_links_include import FileWithMediaLinksInclude
    from .filesize_match import FilesizeMatch
    from .filters import Filters
    from .filters_event_type import FiltersEventType
    from .filters_resource_type import FiltersResourceType
    from .folder import Folder
    from .folder_assets_with_includes_response import FolderAssetsWithIncludesResponse
    from .folder_response import FolderResponse
    from .folder_sort import FolderSort
    from .folder_with_includes import FolderWithIncludes
    from .folder_with_includes_response import FolderWithIncludesResponse
    from .folders_with_includes_response import FoldersWithIncludesResponse
    from .forbidden import Forbidden
    from .forbidden_errors_item import ForbiddenErrorsItem
    from .forbidden_errors_item_source import ForbiddenErrorsItemSource
    from .format_match import FormatMatch
    from .frame_rate_match import FrameRateMatch
    from .group_common import GroupCommon
    from .group_common_source import GroupCommonSource
    from .group_common_with_includes import GroupCommonWithIncludes
    from .group_response import GroupResponse
    from .group_with_includes import GroupWithIncludes
    from .group_with_includes_response import GroupWithIncludesResponse
    from .groups_include import GroupsInclude
    from .groups_sort import GroupsSort
    from .groups_with_includes_response import GroupsWithIncludesResponse
    from .has_alpha_channel_match import HasAlphaChannelMatch
    from .include import Include
    from .include_total_count import IncludeTotalCount
    from .inserted_at_match import InsertedAtMatch
    from .integer_value import IntegerValue
    from .json_error_response import JsonErrorResponse
    from .json_error_response_errors_item import JsonErrorResponseErrorsItem
    from .json_error_response_errors_item_source import JsonErrorResponseErrorsItemSource
    from .keywords_match import KeywordsMatch
    from .link import Link
    from .link_params import LinkParams
    from .links import Links
    from .long_text_definition import LongTextDefinition
    from .long_text_definition_field_configuration import LongTextDefinitionFieldConfiguration
    from .long_text_definition_params import LongTextDefinitionParams
    from .long_text_definition_with_includes import LongTextDefinitionWithIncludes
    from .media_link_common import MediaLinkCommon
    from .media_links_collection import MediaLinksCollection
    from .mention import Mention
    from .metadata_field import MetadataField
    from .metadata_response import MetadataResponse
    from .metadata_with_definition import MetadataWithDefinition
    from .multi_select_value import MultiSelectValue
    from .multi_user_value import MultiUserValue
    from .multi_user_value_member_options_type import MultiUserValueMemberOptionsType
    from .name_match import NameMatch
    from .no_content import NoContent
    from .not_found import NotFound
    from .not_found_errors_item import NotFoundErrorsItem
    from .not_found_errors_item_source import NotFoundErrorsItemSource
    from .notes_match import NotesMatch
    from .number_definition import NumberDefinition
    from .number_definition_field_configuration import NumberDefinitionFieldConfiguration
    from .number_definition_field_configuration_number_format import NumberDefinitionFieldConfigurationNumberFormat
    from .number_definition_params import NumberDefinitionParams
    from .number_definition_params_field_configuration import NumberDefinitionParamsFieldConfiguration
    from .number_definition_params_field_configuration_number_format import (
        NumberDefinitionParamsFieldConfigurationNumberFormat,
    )
    from .number_definition_with_includes import NumberDefinitionWithIncludes
    from .number_value import NumberValue
    from .original_media_link import OriginalMediaLink
    from .page_count_match import PageCountMatch
    from .project import Project
    from .project_include import ProjectInclude
    from .project_match import ProjectMatch
    from .project_match_info import ProjectMatchInfo
    from .project_match_project import ProjectMatchProject
    from .project_search_result import ProjectSearchResult
    from .project_sort import ProjectSort
    from .project_status import ProjectStatus
    from .project_user_roles_response import ProjectUserRolesResponse
    from .project_with_includes import ProjectWithIncludes
    from .projects_with_includes_response import ProjectsWithIncludesResponse
    from .rating_definition import RatingDefinition
    from .rating_definition_field_configuration import RatingDefinitionFieldConfiguration
    from .rating_definition_field_configuration_style import RatingDefinitionFieldConfigurationStyle
    from .rating_definition_params import RatingDefinitionParams
    from .rating_definition_params_field_configuration import RatingDefinitionParamsFieldConfiguration
    from .rating_definition_params_field_configuration_style import RatingDefinitionParamsFieldConfigurationStyle
    from .rating_definition_with_includes import RatingDefinitionWithIncludes
    from .rating_match import RatingMatch
    from .rendition_media_link import RenditionMediaLink
    from .request_after_opaque_cursor import RequestAfterOpaqueCursor
    from .request_page_size import RequestPageSize
    from .resolution_height_match import ResolutionHeightMatch
    from .resolution_width_match import ResolutionWidthMatch
    from .reviewers_sort import ReviewersSort
    from .scrub_sheet_media_link import ScrubSheetMediaLink
    from .scrub_sheet_media_link_metadata import ScrubSheetMediaLinkMetadata
    from .search_match import SearchMatch
    from .search_response import SearchResponse
    from .search_response_data_item import SearchResponseDataItem
    from .select_definition import SelectDefinition
    from .select_definition_field_configuration import SelectDefinitionFieldConfiguration
    from .select_definition_field_configuration_options_item import SelectDefinitionFieldConfigurationOptionsItem
    from .select_definition_params import SelectDefinitionParams
    from .select_definition_params_field_configuration import SelectDefinitionParamsFieldConfiguration
    from .select_definition_params_field_configuration_options_item import (
        SelectDefinitionParamsFieldConfigurationOptionsItem,
    )
    from .select_definition_with_includes import SelectDefinitionWithIncludes
    from .select_multi_definition import SelectMultiDefinition
    from .select_multi_definition_field_configuration import SelectMultiDefinitionFieldConfiguration
    from .select_multi_definition_field_configuration_options_item import (
        SelectMultiDefinitionFieldConfigurationOptionsItem,
    )
    from .select_multi_definition_params import SelectMultiDefinitionParams
    from .select_multi_definition_params_field_configuration import SelectMultiDefinitionParamsFieldConfiguration
    from .select_multi_definition_params_field_configuration_options_item import (
        SelectMultiDefinitionParamsFieldConfigurationOptionsItem,
    )
    from .select_multi_definition_with_includes import SelectMultiDefinitionWithIncludes
    from .select_option import SelectOption
    from .select_value import SelectValue
    from .share import Share
    from .share_access import ShareAccess
    from .share_reviewers_response import ShareReviewersResponse
    from .share_sort import ShareSort
    from .shares_response import SharesResponse
    from .single_user_value import SingleUserValue
    from .single_user_value_member_options_type import SingleUserValueMemberOptionsType
    from .source_filename_match import SourceFilenameMatch
    from .status_match import StatusMatch
    from .sync_group_with_includes import SyncGroupWithIncludes
    from .sync_group_with_includes_sync_status import SyncGroupWithIncludesSyncStatus
    from .text_definition import TextDefinition
    from .text_definition_field_configuration import TextDefinitionFieldConfiguration
    from .text_definition_params import TextDefinitionParams
    from .text_definition_with_includes import TextDefinitionWithIncludes
    from .text_review_annotation import TextReviewAnnotation
    from .text_review_annotation_bounds import TextReviewAnnotationBounds
    from .text_review_annotation_text_review_annotation_type import TextReviewAnnotationTextReviewAnnotationType
    from .text_review_annotation_update import TextReviewAnnotationUpdate
    from .text_review_annotation_update_text_review_annotation_type import (
        TextReviewAnnotationUpdateTextReviewAnnotationType,
    )
    from .text_value import TextValue
    from .time_stamp import TimeStamp
    from .toggle_definition import ToggleDefinition
    from .toggle_definition_field_configuration import ToggleDefinitionFieldConfiguration
    from .toggle_definition_params import ToggleDefinitionParams
    from .toggle_definition_params_field_configuration import ToggleDefinitionParamsFieldConfiguration
    from .toggle_definition_with_includes import ToggleDefinitionWithIncludes
    from .too_many_requests import TooManyRequests
    from .too_many_requests_errors_item import TooManyRequestsErrorsItem
    from .too_many_requests_errors_item_source import TooManyRequestsErrorsItemSource
    from .transcription_match import TranscriptionMatch
    from .transcription_match_matches_item import TranscriptionMatchMatchesItem
    from .unauthorized import Unauthorized
    from .unauthorized_errors_item import UnauthorizedErrorsItem
    from .unauthorized_errors_item_source import UnauthorizedErrorsItemSource
    from .unprocessable_content import UnprocessableContent
    from .unprocessable_content_errors_item import UnprocessableContentErrorsItem
    from .unprocessable_content_errors_item_source import UnprocessableContentErrorsItemSource
    from .update_account_roles_response import UpdateAccountRolesResponse
    from .update_date_definition_params import UpdateDateDefinitionParams
    from .update_date_definition_params_field_configuration import UpdateDateDefinitionParamsFieldConfiguration
    from .update_date_definition_params_field_configuration_display_format import (
        UpdateDateDefinitionParamsFieldConfigurationDisplayFormat,
    )
    from .update_date_definition_params_field_configuration_time_format import (
        UpdateDateDefinitionParamsFieldConfigurationTimeFormat,
    )
    from .update_long_text_definition_params import UpdateLongTextDefinitionParams
    from .update_number_definition_params import UpdateNumberDefinitionParams
    from .update_number_definition_params_field_configuration import UpdateNumberDefinitionParamsFieldConfiguration
    from .update_number_definition_params_field_configuration_number_format import (
        UpdateNumberDefinitionParamsFieldConfigurationNumberFormat,
    )
    from .update_rating_definition_params import UpdateRatingDefinitionParams
    from .update_rating_definition_params_field_configuration import UpdateRatingDefinitionParamsFieldConfiguration
    from .update_rating_definition_params_field_configuration_style import (
        UpdateRatingDefinitionParamsFieldConfigurationStyle,
    )
    from .update_select_definition_params import UpdateSelectDefinitionParams
    from .update_select_definition_params_field_configuration import UpdateSelectDefinitionParamsFieldConfiguration
    from .update_select_definition_params_field_configuration_options_item import (
        UpdateSelectDefinitionParamsFieldConfigurationOptionsItem,
    )
    from .update_select_multi_definition_params import UpdateSelectMultiDefinitionParams
    from .update_select_multi_definition_params_field_configuration import (
        UpdateSelectMultiDefinitionParamsFieldConfiguration,
    )
    from .update_select_multi_definition_params_field_configuration_options_item import (
        UpdateSelectMultiDefinitionParamsFieldConfigurationOptionsItem,
    )
    from .update_text_definition_params import UpdateTextDefinitionParams
    from .update_toggle_definition_params import UpdateToggleDefinitionParams
    from .update_toggle_definition_params_field_configuration import UpdateToggleDefinitionParamsFieldConfiguration
    from .update_user_multi_definition_params import UpdateUserMultiDefinitionParams
    from .update_user_multi_definition_params_field_configuration import (
        UpdateUserMultiDefinitionParamsFieldConfiguration,
    )
    from .update_user_multi_definition_params_field_configuration_custom_members_item import (
        UpdateUserMultiDefinitionParamsFieldConfigurationCustomMembersItem,
    )
    from .update_user_multi_definition_params_field_configuration_custom_members_item_type import (
        UpdateUserMultiDefinitionParamsFieldConfigurationCustomMembersItemType,
    )
    from .update_user_multi_definition_params_field_configuration_member_options_type import (
        UpdateUserMultiDefinitionParamsFieldConfigurationMemberOptionsType,
    )
    from .update_user_roles_response import UpdateUserRolesResponse
    from .update_user_roles_response_data import UpdateUserRolesResponseData
    from .update_user_roles_response_data_role import UpdateUserRolesResponseDataRole
    from .update_user_single_definition_params import UpdateUserSingleDefinitionParams
    from .update_user_single_definition_params_field_configuration import (
        UpdateUserSingleDefinitionParamsFieldConfiguration,
    )
    from .update_user_single_definition_params_field_configuration_custom_members_item import (
        UpdateUserSingleDefinitionParamsFieldConfigurationCustomMembersItem,
    )
    from .update_user_single_definition_params_field_configuration_custom_members_item_type import (
        UpdateUserSingleDefinitionParamsFieldConfigurationCustomMembersItemType,
    )
    from .update_user_single_definition_params_field_configuration_member_options_type import (
        UpdateUserSingleDefinitionParamsFieldConfigurationMemberOptionsType,
    )
    from .updated_at_match import UpdatedAtMatch
    from .uploaded_at_match import UploadedAtMatch
    from .user import User
    from .user_multi_definition import UserMultiDefinition
    from .user_multi_definition_field_configuration import UserMultiDefinitionFieldConfiguration
    from .user_multi_definition_field_configuration_custom_members_item import (
        UserMultiDefinitionFieldConfigurationCustomMembersItem,
    )
    from .user_multi_definition_field_configuration_custom_members_item_type import (
        UserMultiDefinitionFieldConfigurationCustomMembersItemType,
    )
    from .user_multi_definition_field_configuration_member_options_type import (
        UserMultiDefinitionFieldConfigurationMemberOptionsType,
    )
    from .user_multi_definition_params import UserMultiDefinitionParams
    from .user_multi_definition_params_field_configuration import UserMultiDefinitionParamsFieldConfiguration
    from .user_multi_definition_params_field_configuration_custom_members_item import (
        UserMultiDefinitionParamsFieldConfigurationCustomMembersItem,
    )
    from .user_multi_definition_params_field_configuration_custom_members_item_type import (
        UserMultiDefinitionParamsFieldConfigurationCustomMembersItemType,
    )
    from .user_multi_definition_params_field_configuration_member_options_type import (
        UserMultiDefinitionParamsFieldConfigurationMemberOptionsType,
    )
    from .user_multi_definition_with_includes import UserMultiDefinitionWithIncludes
    from .user_role import UserRole
    from .user_role_role import UserRoleRole
    from .user_role_sort import UserRoleSort
    from .user_roles_response import UserRolesResponse
    from .user_single_definition import UserSingleDefinition
    from .user_single_definition_field_configuration import UserSingleDefinitionFieldConfiguration
    from .user_single_definition_field_configuration_custom_members_item import (
        UserSingleDefinitionFieldConfigurationCustomMembersItem,
    )
    from .user_single_definition_field_configuration_custom_members_item_type import (
        UserSingleDefinitionFieldConfigurationCustomMembersItemType,
    )
    from .user_single_definition_field_configuration_member_options_type import (
        UserSingleDefinitionFieldConfigurationMemberOptionsType,
    )
    from .user_single_definition_params import UserSingleDefinitionParams
    from .user_single_definition_params_field_configuration import UserSingleDefinitionParamsFieldConfiguration
    from .user_single_definition_params_field_configuration_custom_members_item import (
        UserSingleDefinitionParamsFieldConfigurationCustomMembersItem,
    )
    from .user_single_definition_params_field_configuration_custom_members_item_type import (
        UserSingleDefinitionParamsFieldConfigurationCustomMembersItemType,
    )
    from .user_single_definition_params_field_configuration_member_options_type import (
        UserSingleDefinitionParamsFieldConfigurationMemberOptionsType,
    )
    from .user_single_definition_with_includes import UserSingleDefinitionWithIncludes
    from .user_value import UserValue
    from .user_value_type import UserValueType
    from .uuid_ import Uuid
    from .version_stack import VersionStack
    from .version_stack_assets_with_includes_response import VersionStackAssetsWithIncludesResponse
    from .version_stack_children_response import VersionStackChildrenResponse
    from .version_stack_response import VersionStackResponse
    from .version_stack_sort_index import VersionStackSortIndex
    from .version_stack_sort_list import VersionStackSortList
    from .version_stack_with_includes import VersionStackWithIncludes
    from .version_stack_with_includes_response import VersionStackWithIncludesResponse
    from .version_stacks_with_includes_response import VersionStacksWithIncludesResponse
    from .visual_match import VisualMatch
    from .visual_match_clip import VisualMatchClip
    from .visual_match_clips_item import VisualMatchClipsItem
    from .webhook import Webhook
    from .webhook_events import WebhookEvents
    from .webhook_sort import WebhookSort
    from .webhook_with_includes import WebhookWithIncludes
    from .webhooks_with_includes_response import WebhooksWithIncludesResponse
    from .workspace import Workspace
    from .workspace_include import WorkspaceInclude
    from .workspace_sort import WorkspaceSort
    from .workspace_user_roles_response import WorkspaceUserRolesResponse
    from .workspace_with_includes import WorkspaceWithIncludes
    from .workspaces_with_includes_response import WorkspacesWithIncludesResponse
_dynamic_imports: typing.Dict[str, str] = {
    "Account": ".account",
    "AccountRoleData": ".account_role_data",
    "AccountRoleDataRole": ".account_role_data_role",
    "AccountRolesItem": ".account_roles_item",
    "AccountSort": ".account_sort",
    "AccountUserRole": ".account_user_role",
    "AccountUserRoleRole": ".account_user_role_role",
    "AccountUserRolesResponse": ".account_user_roles_response",
    "AccountUserSort": ".account_user_sort",
    "AccountsResponse": ".accounts_response",
    "Action": ".action",
    "ActionCreateResponse": ".action_create_response",
    "ActionCreateResponseData": ".action_create_response_data",
    "ActionResponse": ".action_response",
    "ActionWithIncludes": ".action_with_includes",
    "ActionWithIncludesResponse": ".action_with_includes_response",
    "ActionsWithIncludesResponse": ".actions_with_includes_response",
    "Anchor": ".anchor",
    "Asset": ".asset",
    "AssetCommon": ".asset_common",
    "AssetCommonType": ".asset_common_type",
    "AssetCommonWithIncludes": ".asset_common_with_includes",
    "AssetCommonWithIncludesType": ".asset_common_with_includes_type",
    "AssetInclude": ".asset_include",
    "AssetSearchResult": ".asset_search_result",
    "AssetSearchResultType": ".asset_search_result_type",
    "AssetWithIncludes": ".asset_with_includes",
    "AssigneeMatch": ".assignee_match",
    "AttachmentInput": ".attachment_input",
    "AudioSampleRateMatch": ".audio_sample_rate_match",
    "AuditLogsInclude": ".audit_logs_include",
    "AuditLogsWithIncludesResponse": ".audit_logs_with_includes_response",
    "AuditLogwithIncludes": ".audit_logwith_includes",
    "AuditLogwithIncludesEventType": ".audit_logwith_includes_event_type",
    "AuditLogwithIncludesResourceType": ".audit_logwith_includes_resource_type",
    "BadRequest": ".bad_request",
    "BadRequestErrorsItem": ".bad_request_errors_item",
    "BadRequestErrorsItemSource": ".bad_request_errors_item_source",
    "BitDepthMatch": ".bit_depth_match",
    "BitRateMatch": ".bit_rate_match",
    "BooleanValue": ".boolean_value",
    "ChannelsMatch": ".channels_match",
    "ChildrenType": ".children_type",
    "CodecMatch": ".codec_match",
    "Collection": ".collection",
    "CollectionAggregationMode": ".collection_aggregation_mode",
    "CollectionInclude": ".collection_include",
    "CollectionResponse": ".collection_response",
    "CollectionsResponse": ".collections_response",
    "ColorSpaceMatch": ".color_space_match",
    "Comment": ".comment",
    "CommentAttachment": ".comment_attachment",
    "CommentAttachmentResponse": ".comment_attachment_response",
    "CommentCountMatch": ".comment_count_match",
    "CommentInclude": ".comment_include",
    "CommentMatch": ".comment_match",
    "CommentResponse": ".comment_response",
    "CommentSort": ".comment_sort",
    "CommentWithIncludes": ".comment_with_includes",
    "CommentWithIncludesResponse": ".comment_with_includes_response",
    "CommentsWithIncludesResponse": ".comments_with_includes_response",
    "Conflict": ".conflict",
    "ConflictErrorsItem": ".conflict_errors_item",
    "ConflictErrorsItemSource": ".conflict_errors_item_source",
    "CreatorMatch": ".creator_match",
    "DateDefinition": ".date_definition",
    "DateDefinitionFieldConfiguration": ".date_definition_field_configuration",
    "DateDefinitionFieldConfigurationDisplayFormat": ".date_definition_field_configuration_display_format",
    "DateDefinitionFieldConfigurationTimeFormat": ".date_definition_field_configuration_time_format",
    "DateDefinitionParams": ".date_definition_params",
    "DateDefinitionParamsFieldConfiguration": ".date_definition_params_field_configuration",
    "DateDefinitionParamsFieldConfigurationDisplayFormat": ".date_definition_params_field_configuration_display_format",
    "DateDefinitionParamsFieldConfigurationTimeFormat": ".date_definition_params_field_configuration_time_format",
    "DateDefinitionWithIncludes": ".date_definition_with_includes",
    "DateValue": ".date_value",
    "DeletedAtMatch": ".deleted_at_match",
    "DurationMatch": ".duration_match",
    "DynamicRangeMatch": ".dynamic_range_match",
    "FieldDefinition": ".field_definition",
    "FieldDefinitionInclude": ".field_definition_include",
    "FieldDefinitionResponse": ".field_definition_response",
    "FieldDefinitionSort": ".field_definition_sort",
    "FieldDefinitionWithIncludes": ".field_definition_with_includes",
    "FieldDefinitionsWithIncludesResponse": ".field_definitions_with_includes_response",
    "FieldValueCommon": ".field_value_common",
    "FieldValueCommonFieldType": ".field_value_common_field_type",
    "File": ".file",
    "FileAssetsWithIncludesResponse": ".file_assets_with_includes_response",
    "FileRemoteUploadResponse": ".file_remote_upload_response",
    "FileResponse": ".file_response",
    "FileSort": ".file_sort",
    "FileStatus": ".file_status",
    "FileTypeMatch": ".file_type_match",
    "FileUploadStatus": ".file_upload_status",
    "FileUploadStatusResponse": ".file_upload_status_response",
    "FileWithIncludes": ".file_with_includes",
    "FileWithIncludesResponse": ".file_with_includes_response",
    "FileWithIncludesStatus": ".file_with_includes_status",
    "FileWithMediaLinksInclude": ".file_with_media_links_include",
    "FilesizeMatch": ".filesize_match",
    "Filters": ".filters",
    "FiltersEventType": ".filters_event_type",
    "FiltersResourceType": ".filters_resource_type",
    "Folder": ".folder",
    "FolderAssetsWithIncludesResponse": ".folder_assets_with_includes_response",
    "FolderResponse": ".folder_response",
    "FolderSort": ".folder_sort",
    "FolderWithIncludes": ".folder_with_includes",
    "FolderWithIncludesResponse": ".folder_with_includes_response",
    "FoldersWithIncludesResponse": ".folders_with_includes_response",
    "Forbidden": ".forbidden",
    "ForbiddenErrorsItem": ".forbidden_errors_item",
    "ForbiddenErrorsItemSource": ".forbidden_errors_item_source",
    "FormatMatch": ".format_match",
    "FrameRateMatch": ".frame_rate_match",
    "GroupCommon": ".group_common",
    "GroupCommonSource": ".group_common_source",
    "GroupCommonWithIncludes": ".group_common_with_includes",
    "GroupResponse": ".group_response",
    "GroupWithIncludes": ".group_with_includes",
    "GroupWithIncludesResponse": ".group_with_includes_response",
    "GroupsInclude": ".groups_include",
    "GroupsSort": ".groups_sort",
    "GroupsWithIncludesResponse": ".groups_with_includes_response",
    "HasAlphaChannelMatch": ".has_alpha_channel_match",
    "Include": ".include",
    "IncludeTotalCount": ".include_total_count",
    "InsertedAtMatch": ".inserted_at_match",
    "IntegerValue": ".integer_value",
    "JsonErrorResponse": ".json_error_response",
    "JsonErrorResponseErrorsItem": ".json_error_response_errors_item",
    "JsonErrorResponseErrorsItemSource": ".json_error_response_errors_item_source",
    "KeywordsMatch": ".keywords_match",
    "Link": ".link",
    "LinkParams": ".link_params",
    "Links": ".links",
    "LongTextDefinition": ".long_text_definition",
    "LongTextDefinitionFieldConfiguration": ".long_text_definition_field_configuration",
    "LongTextDefinitionParams": ".long_text_definition_params",
    "LongTextDefinitionWithIncludes": ".long_text_definition_with_includes",
    "MediaLinkCommon": ".media_link_common",
    "MediaLinksCollection": ".media_links_collection",
    "Mention": ".mention",
    "MetadataField": ".metadata_field",
    "MetadataResponse": ".metadata_response",
    "MetadataWithDefinition": ".metadata_with_definition",
    "MultiSelectValue": ".multi_select_value",
    "MultiUserValue": ".multi_user_value",
    "MultiUserValueMemberOptionsType": ".multi_user_value_member_options_type",
    "NameMatch": ".name_match",
    "NoContent": ".no_content",
    "NotFound": ".not_found",
    "NotFoundErrorsItem": ".not_found_errors_item",
    "NotFoundErrorsItemSource": ".not_found_errors_item_source",
    "NotesMatch": ".notes_match",
    "NumberDefinition": ".number_definition",
    "NumberDefinitionFieldConfiguration": ".number_definition_field_configuration",
    "NumberDefinitionFieldConfigurationNumberFormat": ".number_definition_field_configuration_number_format",
    "NumberDefinitionParams": ".number_definition_params",
    "NumberDefinitionParamsFieldConfiguration": ".number_definition_params_field_configuration",
    "NumberDefinitionParamsFieldConfigurationNumberFormat": ".number_definition_params_field_configuration_number_format",
    "NumberDefinitionWithIncludes": ".number_definition_with_includes",
    "NumberValue": ".number_value",
    "OriginalMediaLink": ".original_media_link",
    "PageCountMatch": ".page_count_match",
    "Project": ".project",
    "ProjectInclude": ".project_include",
    "ProjectMatch": ".project_match",
    "ProjectMatchInfo": ".project_match_info",
    "ProjectMatchProject": ".project_match_project",
    "ProjectSearchResult": ".project_search_result",
    "ProjectSort": ".project_sort",
    "ProjectStatus": ".project_status",
    "ProjectUserRolesResponse": ".project_user_roles_response",
    "ProjectWithIncludes": ".project_with_includes",
    "ProjectsWithIncludesResponse": ".projects_with_includes_response",
    "RatingDefinition": ".rating_definition",
    "RatingDefinitionFieldConfiguration": ".rating_definition_field_configuration",
    "RatingDefinitionFieldConfigurationStyle": ".rating_definition_field_configuration_style",
    "RatingDefinitionParams": ".rating_definition_params",
    "RatingDefinitionParamsFieldConfiguration": ".rating_definition_params_field_configuration",
    "RatingDefinitionParamsFieldConfigurationStyle": ".rating_definition_params_field_configuration_style",
    "RatingDefinitionWithIncludes": ".rating_definition_with_includes",
    "RatingMatch": ".rating_match",
    "RenditionMediaLink": ".rendition_media_link",
    "RequestAfterOpaqueCursor": ".request_after_opaque_cursor",
    "RequestPageSize": ".request_page_size",
    "ResolutionHeightMatch": ".resolution_height_match",
    "ResolutionWidthMatch": ".resolution_width_match",
    "ReviewersSort": ".reviewers_sort",
    "ScrubSheetMediaLink": ".scrub_sheet_media_link",
    "ScrubSheetMediaLinkMetadata": ".scrub_sheet_media_link_metadata",
    "SearchMatch": ".search_match",
    "SearchResponse": ".search_response",
    "SearchResponseDataItem": ".search_response_data_item",
    "SelectDefinition": ".select_definition",
    "SelectDefinitionFieldConfiguration": ".select_definition_field_configuration",
    "SelectDefinitionFieldConfigurationOptionsItem": ".select_definition_field_configuration_options_item",
    "SelectDefinitionParams": ".select_definition_params",
    "SelectDefinitionParamsFieldConfiguration": ".select_definition_params_field_configuration",
    "SelectDefinitionParamsFieldConfigurationOptionsItem": ".select_definition_params_field_configuration_options_item",
    "SelectDefinitionWithIncludes": ".select_definition_with_includes",
    "SelectMultiDefinition": ".select_multi_definition",
    "SelectMultiDefinitionFieldConfiguration": ".select_multi_definition_field_configuration",
    "SelectMultiDefinitionFieldConfigurationOptionsItem": ".select_multi_definition_field_configuration_options_item",
    "SelectMultiDefinitionParams": ".select_multi_definition_params",
    "SelectMultiDefinitionParamsFieldConfiguration": ".select_multi_definition_params_field_configuration",
    "SelectMultiDefinitionParamsFieldConfigurationOptionsItem": ".select_multi_definition_params_field_configuration_options_item",
    "SelectMultiDefinitionWithIncludes": ".select_multi_definition_with_includes",
    "SelectOption": ".select_option",
    "SelectValue": ".select_value",
    "Share": ".share",
    "ShareAccess": ".share_access",
    "ShareReviewersResponse": ".share_reviewers_response",
    "ShareSort": ".share_sort",
    "SharesResponse": ".shares_response",
    "SingleUserValue": ".single_user_value",
    "SingleUserValueMemberOptionsType": ".single_user_value_member_options_type",
    "SourceFilenameMatch": ".source_filename_match",
    "StatusMatch": ".status_match",
    "SyncGroupWithIncludes": ".sync_group_with_includes",
    "SyncGroupWithIncludesSyncStatus": ".sync_group_with_includes_sync_status",
    "TextDefinition": ".text_definition",
    "TextDefinitionFieldConfiguration": ".text_definition_field_configuration",
    "TextDefinitionParams": ".text_definition_params",
    "TextDefinitionWithIncludes": ".text_definition_with_includes",
    "TextReviewAnnotation": ".text_review_annotation",
    "TextReviewAnnotationBounds": ".text_review_annotation_bounds",
    "TextReviewAnnotationTextReviewAnnotationType": ".text_review_annotation_text_review_annotation_type",
    "TextReviewAnnotationUpdate": ".text_review_annotation_update",
    "TextReviewAnnotationUpdateTextReviewAnnotationType": ".text_review_annotation_update_text_review_annotation_type",
    "TextValue": ".text_value",
    "TimeStamp": ".time_stamp",
    "ToggleDefinition": ".toggle_definition",
    "ToggleDefinitionFieldConfiguration": ".toggle_definition_field_configuration",
    "ToggleDefinitionParams": ".toggle_definition_params",
    "ToggleDefinitionParamsFieldConfiguration": ".toggle_definition_params_field_configuration",
    "ToggleDefinitionWithIncludes": ".toggle_definition_with_includes",
    "TooManyRequests": ".too_many_requests",
    "TooManyRequestsErrorsItem": ".too_many_requests_errors_item",
    "TooManyRequestsErrorsItemSource": ".too_many_requests_errors_item_source",
    "TranscriptionMatch": ".transcription_match",
    "TranscriptionMatchMatchesItem": ".transcription_match_matches_item",
    "Unauthorized": ".unauthorized",
    "UnauthorizedErrorsItem": ".unauthorized_errors_item",
    "UnauthorizedErrorsItemSource": ".unauthorized_errors_item_source",
    "UnprocessableContent": ".unprocessable_content",
    "UnprocessableContentErrorsItem": ".unprocessable_content_errors_item",
    "UnprocessableContentErrorsItemSource": ".unprocessable_content_errors_item_source",
    "UpdateAccountRolesResponse": ".update_account_roles_response",
    "UpdateDateDefinitionParams": ".update_date_definition_params",
    "UpdateDateDefinitionParamsFieldConfiguration": ".update_date_definition_params_field_configuration",
    "UpdateDateDefinitionParamsFieldConfigurationDisplayFormat": ".update_date_definition_params_field_configuration_display_format",
    "UpdateDateDefinitionParamsFieldConfigurationTimeFormat": ".update_date_definition_params_field_configuration_time_format",
    "UpdateLongTextDefinitionParams": ".update_long_text_definition_params",
    "UpdateNumberDefinitionParams": ".update_number_definition_params",
    "UpdateNumberDefinitionParamsFieldConfiguration": ".update_number_definition_params_field_configuration",
    "UpdateNumberDefinitionParamsFieldConfigurationNumberFormat": ".update_number_definition_params_field_configuration_number_format",
    "UpdateRatingDefinitionParams": ".update_rating_definition_params",
    "UpdateRatingDefinitionParamsFieldConfiguration": ".update_rating_definition_params_field_configuration",
    "UpdateRatingDefinitionParamsFieldConfigurationStyle": ".update_rating_definition_params_field_configuration_style",
    "UpdateSelectDefinitionParams": ".update_select_definition_params",
    "UpdateSelectDefinitionParamsFieldConfiguration": ".update_select_definition_params_field_configuration",
    "UpdateSelectDefinitionParamsFieldConfigurationOptionsItem": ".update_select_definition_params_field_configuration_options_item",
    "UpdateSelectMultiDefinitionParams": ".update_select_multi_definition_params",
    "UpdateSelectMultiDefinitionParamsFieldConfiguration": ".update_select_multi_definition_params_field_configuration",
    "UpdateSelectMultiDefinitionParamsFieldConfigurationOptionsItem": ".update_select_multi_definition_params_field_configuration_options_item",
    "UpdateTextDefinitionParams": ".update_text_definition_params",
    "UpdateToggleDefinitionParams": ".update_toggle_definition_params",
    "UpdateToggleDefinitionParamsFieldConfiguration": ".update_toggle_definition_params_field_configuration",
    "UpdateUserMultiDefinitionParams": ".update_user_multi_definition_params",
    "UpdateUserMultiDefinitionParamsFieldConfiguration": ".update_user_multi_definition_params_field_configuration",
    "UpdateUserMultiDefinitionParamsFieldConfigurationCustomMembersItem": ".update_user_multi_definition_params_field_configuration_custom_members_item",
    "UpdateUserMultiDefinitionParamsFieldConfigurationCustomMembersItemType": ".update_user_multi_definition_params_field_configuration_custom_members_item_type",
    "UpdateUserMultiDefinitionParamsFieldConfigurationMemberOptionsType": ".update_user_multi_definition_params_field_configuration_member_options_type",
    "UpdateUserRolesResponse": ".update_user_roles_response",
    "UpdateUserRolesResponseData": ".update_user_roles_response_data",
    "UpdateUserRolesResponseDataRole": ".update_user_roles_response_data_role",
    "UpdateUserSingleDefinitionParams": ".update_user_single_definition_params",
    "UpdateUserSingleDefinitionParamsFieldConfiguration": ".update_user_single_definition_params_field_configuration",
    "UpdateUserSingleDefinitionParamsFieldConfigurationCustomMembersItem": ".update_user_single_definition_params_field_configuration_custom_members_item",
    "UpdateUserSingleDefinitionParamsFieldConfigurationCustomMembersItemType": ".update_user_single_definition_params_field_configuration_custom_members_item_type",
    "UpdateUserSingleDefinitionParamsFieldConfigurationMemberOptionsType": ".update_user_single_definition_params_field_configuration_member_options_type",
    "UpdatedAtMatch": ".updated_at_match",
    "UploadedAtMatch": ".uploaded_at_match",
    "User": ".user",
    "UserMultiDefinition": ".user_multi_definition",
    "UserMultiDefinitionFieldConfiguration": ".user_multi_definition_field_configuration",
    "UserMultiDefinitionFieldConfigurationCustomMembersItem": ".user_multi_definition_field_configuration_custom_members_item",
    "UserMultiDefinitionFieldConfigurationCustomMembersItemType": ".user_multi_definition_field_configuration_custom_members_item_type",
    "UserMultiDefinitionFieldConfigurationMemberOptionsType": ".user_multi_definition_field_configuration_member_options_type",
    "UserMultiDefinitionParams": ".user_multi_definition_params",
    "UserMultiDefinitionParamsFieldConfiguration": ".user_multi_definition_params_field_configuration",
    "UserMultiDefinitionParamsFieldConfigurationCustomMembersItem": ".user_multi_definition_params_field_configuration_custom_members_item",
    "UserMultiDefinitionParamsFieldConfigurationCustomMembersItemType": ".user_multi_definition_params_field_configuration_custom_members_item_type",
    "UserMultiDefinitionParamsFieldConfigurationMemberOptionsType": ".user_multi_definition_params_field_configuration_member_options_type",
    "UserMultiDefinitionWithIncludes": ".user_multi_definition_with_includes",
    "UserRole": ".user_role",
    "UserRoleRole": ".user_role_role",
    "UserRoleSort": ".user_role_sort",
    "UserRolesResponse": ".user_roles_response",
    "UserSingleDefinition": ".user_single_definition",
    "UserSingleDefinitionFieldConfiguration": ".user_single_definition_field_configuration",
    "UserSingleDefinitionFieldConfigurationCustomMembersItem": ".user_single_definition_field_configuration_custom_members_item",
    "UserSingleDefinitionFieldConfigurationCustomMembersItemType": ".user_single_definition_field_configuration_custom_members_item_type",
    "UserSingleDefinitionFieldConfigurationMemberOptionsType": ".user_single_definition_field_configuration_member_options_type",
    "UserSingleDefinitionParams": ".user_single_definition_params",
    "UserSingleDefinitionParamsFieldConfiguration": ".user_single_definition_params_field_configuration",
    "UserSingleDefinitionParamsFieldConfigurationCustomMembersItem": ".user_single_definition_params_field_configuration_custom_members_item",
    "UserSingleDefinitionParamsFieldConfigurationCustomMembersItemType": ".user_single_definition_params_field_configuration_custom_members_item_type",
    "UserSingleDefinitionParamsFieldConfigurationMemberOptionsType": ".user_single_definition_params_field_configuration_member_options_type",
    "UserSingleDefinitionWithIncludes": ".user_single_definition_with_includes",
    "UserValue": ".user_value",
    "UserValueType": ".user_value_type",
    "Uuid": ".uuid_",
    "VersionStack": ".version_stack",
    "VersionStackAssetsWithIncludesResponse": ".version_stack_assets_with_includes_response",
    "VersionStackChildrenResponse": ".version_stack_children_response",
    "VersionStackResponse": ".version_stack_response",
    "VersionStackSortIndex": ".version_stack_sort_index",
    "VersionStackSortList": ".version_stack_sort_list",
    "VersionStackWithIncludes": ".version_stack_with_includes",
    "VersionStackWithIncludesResponse": ".version_stack_with_includes_response",
    "VersionStacksWithIncludesResponse": ".version_stacks_with_includes_response",
    "VisualMatch": ".visual_match",
    "VisualMatchClip": ".visual_match_clip",
    "VisualMatchClipsItem": ".visual_match_clips_item",
    "Webhook": ".webhook",
    "WebhookEvents": ".webhook_events",
    "WebhookSort": ".webhook_sort",
    "WebhookWithIncludes": ".webhook_with_includes",
    "WebhooksWithIncludesResponse": ".webhooks_with_includes_response",
    "Workspace": ".workspace",
    "WorkspaceInclude": ".workspace_include",
    "WorkspaceSort": ".workspace_sort",
    "WorkspaceUserRolesResponse": ".workspace_user_roles_response",
    "WorkspaceWithIncludes": ".workspace_with_includes",
    "WorkspacesWithIncludesResponse": ".workspaces_with_includes_response",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "Account",
    "AccountRoleData",
    "AccountRoleDataRole",
    "AccountRolesItem",
    "AccountSort",
    "AccountUserRole",
    "AccountUserRoleRole",
    "AccountUserRolesResponse",
    "AccountUserSort",
    "AccountsResponse",
    "Action",
    "ActionCreateResponse",
    "ActionCreateResponseData",
    "ActionResponse",
    "ActionWithIncludes",
    "ActionWithIncludesResponse",
    "ActionsWithIncludesResponse",
    "Anchor",
    "Asset",
    "AssetCommon",
    "AssetCommonType",
    "AssetCommonWithIncludes",
    "AssetCommonWithIncludesType",
    "AssetInclude",
    "AssetSearchResult",
    "AssetSearchResultType",
    "AssetWithIncludes",
    "AssigneeMatch",
    "AttachmentInput",
    "AudioSampleRateMatch",
    "AuditLogsInclude",
    "AuditLogsWithIncludesResponse",
    "AuditLogwithIncludes",
    "AuditLogwithIncludesEventType",
    "AuditLogwithIncludesResourceType",
    "BadRequest",
    "BadRequestErrorsItem",
    "BadRequestErrorsItemSource",
    "BitDepthMatch",
    "BitRateMatch",
    "BooleanValue",
    "ChannelsMatch",
    "ChildrenType",
    "CodecMatch",
    "Collection",
    "CollectionAggregationMode",
    "CollectionInclude",
    "CollectionResponse",
    "CollectionsResponse",
    "ColorSpaceMatch",
    "Comment",
    "CommentAttachment",
    "CommentAttachmentResponse",
    "CommentCountMatch",
    "CommentInclude",
    "CommentMatch",
    "CommentResponse",
    "CommentSort",
    "CommentWithIncludes",
    "CommentWithIncludesResponse",
    "CommentsWithIncludesResponse",
    "Conflict",
    "ConflictErrorsItem",
    "ConflictErrorsItemSource",
    "CreatorMatch",
    "DateDefinition",
    "DateDefinitionFieldConfiguration",
    "DateDefinitionFieldConfigurationDisplayFormat",
    "DateDefinitionFieldConfigurationTimeFormat",
    "DateDefinitionParams",
    "DateDefinitionParamsFieldConfiguration",
    "DateDefinitionParamsFieldConfigurationDisplayFormat",
    "DateDefinitionParamsFieldConfigurationTimeFormat",
    "DateDefinitionWithIncludes",
    "DateValue",
    "DeletedAtMatch",
    "DurationMatch",
    "DynamicRangeMatch",
    "FieldDefinition",
    "FieldDefinitionInclude",
    "FieldDefinitionResponse",
    "FieldDefinitionSort",
    "FieldDefinitionWithIncludes",
    "FieldDefinitionsWithIncludesResponse",
    "FieldValueCommon",
    "FieldValueCommonFieldType",
    "File",
    "FileAssetsWithIncludesResponse",
    "FileRemoteUploadResponse",
    "FileResponse",
    "FileSort",
    "FileStatus",
    "FileTypeMatch",
    "FileUploadStatus",
    "FileUploadStatusResponse",
    "FileWithIncludes",
    "FileWithIncludesResponse",
    "FileWithIncludesStatus",
    "FileWithMediaLinksInclude",
    "FilesizeMatch",
    "Filters",
    "FiltersEventType",
    "FiltersResourceType",
    "Folder",
    "FolderAssetsWithIncludesResponse",
    "FolderResponse",
    "FolderSort",
    "FolderWithIncludes",
    "FolderWithIncludesResponse",
    "FoldersWithIncludesResponse",
    "Forbidden",
    "ForbiddenErrorsItem",
    "ForbiddenErrorsItemSource",
    "FormatMatch",
    "FrameRateMatch",
    "GroupCommon",
    "GroupCommonSource",
    "GroupCommonWithIncludes",
    "GroupResponse",
    "GroupWithIncludes",
    "GroupWithIncludesResponse",
    "GroupsInclude",
    "GroupsSort",
    "GroupsWithIncludesResponse",
    "HasAlphaChannelMatch",
    "Include",
    "IncludeTotalCount",
    "InsertedAtMatch",
    "IntegerValue",
    "JsonErrorResponse",
    "JsonErrorResponseErrorsItem",
    "JsonErrorResponseErrorsItemSource",
    "KeywordsMatch",
    "Link",
    "LinkParams",
    "Links",
    "LongTextDefinition",
    "LongTextDefinitionFieldConfiguration",
    "LongTextDefinitionParams",
    "LongTextDefinitionWithIncludes",
    "MediaLinkCommon",
    "MediaLinksCollection",
    "Mention",
    "MetadataField",
    "MetadataResponse",
    "MetadataWithDefinition",
    "MultiSelectValue",
    "MultiUserValue",
    "MultiUserValueMemberOptionsType",
    "NameMatch",
    "NoContent",
    "NotFound",
    "NotFoundErrorsItem",
    "NotFoundErrorsItemSource",
    "NotesMatch",
    "NumberDefinition",
    "NumberDefinitionFieldConfiguration",
    "NumberDefinitionFieldConfigurationNumberFormat",
    "NumberDefinitionParams",
    "NumberDefinitionParamsFieldConfiguration",
    "NumberDefinitionParamsFieldConfigurationNumberFormat",
    "NumberDefinitionWithIncludes",
    "NumberValue",
    "OriginalMediaLink",
    "PageCountMatch",
    "Project",
    "ProjectInclude",
    "ProjectMatch",
    "ProjectMatchInfo",
    "ProjectMatchProject",
    "ProjectSearchResult",
    "ProjectSort",
    "ProjectStatus",
    "ProjectUserRolesResponse",
    "ProjectWithIncludes",
    "ProjectsWithIncludesResponse",
    "RatingDefinition",
    "RatingDefinitionFieldConfiguration",
    "RatingDefinitionFieldConfigurationStyle",
    "RatingDefinitionParams",
    "RatingDefinitionParamsFieldConfiguration",
    "RatingDefinitionParamsFieldConfigurationStyle",
    "RatingDefinitionWithIncludes",
    "RatingMatch",
    "RenditionMediaLink",
    "RequestAfterOpaqueCursor",
    "RequestPageSize",
    "ResolutionHeightMatch",
    "ResolutionWidthMatch",
    "ReviewersSort",
    "ScrubSheetMediaLink",
    "ScrubSheetMediaLinkMetadata",
    "SearchMatch",
    "SearchResponse",
    "SearchResponseDataItem",
    "SelectDefinition",
    "SelectDefinitionFieldConfiguration",
    "SelectDefinitionFieldConfigurationOptionsItem",
    "SelectDefinitionParams",
    "SelectDefinitionParamsFieldConfiguration",
    "SelectDefinitionParamsFieldConfigurationOptionsItem",
    "SelectDefinitionWithIncludes",
    "SelectMultiDefinition",
    "SelectMultiDefinitionFieldConfiguration",
    "SelectMultiDefinitionFieldConfigurationOptionsItem",
    "SelectMultiDefinitionParams",
    "SelectMultiDefinitionParamsFieldConfiguration",
    "SelectMultiDefinitionParamsFieldConfigurationOptionsItem",
    "SelectMultiDefinitionWithIncludes",
    "SelectOption",
    "SelectValue",
    "Share",
    "ShareAccess",
    "ShareReviewersResponse",
    "ShareSort",
    "SharesResponse",
    "SingleUserValue",
    "SingleUserValueMemberOptionsType",
    "SourceFilenameMatch",
    "StatusMatch",
    "SyncGroupWithIncludes",
    "SyncGroupWithIncludesSyncStatus",
    "TextDefinition",
    "TextDefinitionFieldConfiguration",
    "TextDefinitionParams",
    "TextDefinitionWithIncludes",
    "TextReviewAnnotation",
    "TextReviewAnnotationBounds",
    "TextReviewAnnotationTextReviewAnnotationType",
    "TextReviewAnnotationUpdate",
    "TextReviewAnnotationUpdateTextReviewAnnotationType",
    "TextValue",
    "TimeStamp",
    "ToggleDefinition",
    "ToggleDefinitionFieldConfiguration",
    "ToggleDefinitionParams",
    "ToggleDefinitionParamsFieldConfiguration",
    "ToggleDefinitionWithIncludes",
    "TooManyRequests",
    "TooManyRequestsErrorsItem",
    "TooManyRequestsErrorsItemSource",
    "TranscriptionMatch",
    "TranscriptionMatchMatchesItem",
    "Unauthorized",
    "UnauthorizedErrorsItem",
    "UnauthorizedErrorsItemSource",
    "UnprocessableContent",
    "UnprocessableContentErrorsItem",
    "UnprocessableContentErrorsItemSource",
    "UpdateAccountRolesResponse",
    "UpdateDateDefinitionParams",
    "UpdateDateDefinitionParamsFieldConfiguration",
    "UpdateDateDefinitionParamsFieldConfigurationDisplayFormat",
    "UpdateDateDefinitionParamsFieldConfigurationTimeFormat",
    "UpdateLongTextDefinitionParams",
    "UpdateNumberDefinitionParams",
    "UpdateNumberDefinitionParamsFieldConfiguration",
    "UpdateNumberDefinitionParamsFieldConfigurationNumberFormat",
    "UpdateRatingDefinitionParams",
    "UpdateRatingDefinitionParamsFieldConfiguration",
    "UpdateRatingDefinitionParamsFieldConfigurationStyle",
    "UpdateSelectDefinitionParams",
    "UpdateSelectDefinitionParamsFieldConfiguration",
    "UpdateSelectDefinitionParamsFieldConfigurationOptionsItem",
    "UpdateSelectMultiDefinitionParams",
    "UpdateSelectMultiDefinitionParamsFieldConfiguration",
    "UpdateSelectMultiDefinitionParamsFieldConfigurationOptionsItem",
    "UpdateTextDefinitionParams",
    "UpdateToggleDefinitionParams",
    "UpdateToggleDefinitionParamsFieldConfiguration",
    "UpdateUserMultiDefinitionParams",
    "UpdateUserMultiDefinitionParamsFieldConfiguration",
    "UpdateUserMultiDefinitionParamsFieldConfigurationCustomMembersItem",
    "UpdateUserMultiDefinitionParamsFieldConfigurationCustomMembersItemType",
    "UpdateUserMultiDefinitionParamsFieldConfigurationMemberOptionsType",
    "UpdateUserRolesResponse",
    "UpdateUserRolesResponseData",
    "UpdateUserRolesResponseDataRole",
    "UpdateUserSingleDefinitionParams",
    "UpdateUserSingleDefinitionParamsFieldConfiguration",
    "UpdateUserSingleDefinitionParamsFieldConfigurationCustomMembersItem",
    "UpdateUserSingleDefinitionParamsFieldConfigurationCustomMembersItemType",
    "UpdateUserSingleDefinitionParamsFieldConfigurationMemberOptionsType",
    "UpdatedAtMatch",
    "UploadedAtMatch",
    "User",
    "UserMultiDefinition",
    "UserMultiDefinitionFieldConfiguration",
    "UserMultiDefinitionFieldConfigurationCustomMembersItem",
    "UserMultiDefinitionFieldConfigurationCustomMembersItemType",
    "UserMultiDefinitionFieldConfigurationMemberOptionsType",
    "UserMultiDefinitionParams",
    "UserMultiDefinitionParamsFieldConfiguration",
    "UserMultiDefinitionParamsFieldConfigurationCustomMembersItem",
    "UserMultiDefinitionParamsFieldConfigurationCustomMembersItemType",
    "UserMultiDefinitionParamsFieldConfigurationMemberOptionsType",
    "UserMultiDefinitionWithIncludes",
    "UserRole",
    "UserRoleRole",
    "UserRoleSort",
    "UserRolesResponse",
    "UserSingleDefinition",
    "UserSingleDefinitionFieldConfiguration",
    "UserSingleDefinitionFieldConfigurationCustomMembersItem",
    "UserSingleDefinitionFieldConfigurationCustomMembersItemType",
    "UserSingleDefinitionFieldConfigurationMemberOptionsType",
    "UserSingleDefinitionParams",
    "UserSingleDefinitionParamsFieldConfiguration",
    "UserSingleDefinitionParamsFieldConfigurationCustomMembersItem",
    "UserSingleDefinitionParamsFieldConfigurationCustomMembersItemType",
    "UserSingleDefinitionParamsFieldConfigurationMemberOptionsType",
    "UserSingleDefinitionWithIncludes",
    "UserValue",
    "UserValueType",
    "Uuid",
    "VersionStack",
    "VersionStackAssetsWithIncludesResponse",
    "VersionStackChildrenResponse",
    "VersionStackResponse",
    "VersionStackSortIndex",
    "VersionStackSortList",
    "VersionStackWithIncludes",
    "VersionStackWithIncludesResponse",
    "VersionStacksWithIncludesResponse",
    "VisualMatch",
    "VisualMatchClip",
    "VisualMatchClipsItem",
    "Webhook",
    "WebhookEvents",
    "WebhookSort",
    "WebhookWithIncludes",
    "WebhooksWithIncludesResponse",
    "Workspace",
    "WorkspaceInclude",
    "WorkspaceSort",
    "WorkspaceUserRolesResponse",
    "WorkspaceWithIncludes",
    "WorkspacesWithIncludesResponse",
]



# This file was auto-generated by Fern from our API Definition.

import typing

from .file import File
from .folder import Folder
from .version_stack import VersionStack

Asset = typing.Union[File, Folder, VersionStack]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel
from .unprocessable_content_errors_item import UnprocessableContentErrorsItem


class UnprocessableContent(UniversalBaseModel):
    errors: typing.List[UnprocessableContentErrorsItem]

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

FieldValueCommonFieldType = typing.Union[
    typing.Literal[
        "text",
        "long_text",
        "select",
        "select_multi",
        "rating",
        "number",
        "toggle",
        "users",
        "date",
        "user_multi",
        "user_single",
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel


class CreatorMatch(UniversalBaseModel):
    """
    The result's creator is a match for the search query
    """

    creator_id: str = pydantic.Field()
    """
    The ID of the user who created the result
    """

    type: typing.Literal["creator_match"] = "creator_match"

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel


class RatingMatch(UniversalBaseModel):
    """
    The result's rating is a match for the search query
    """

    color: typing.Optional[str] = pydantic.Field(default=None)
    """
    The color of the rating field
    """

    max_value: typing.Optional[int] = pydantic.Field(default=None)
    """
    The maximum rating of the rating field for the result
    """

    rating: int = pydantic.Field()
    """
    The rating of the result
    """

    style: typing.Optional[str] = pydantic.Field(default=None)
    """
    The style of the rating field
    """

    type: typing.Literal["rating_match"] = "rating_match"

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from .group_common_with_includes import GroupCommonWithIncludes
from .sync_group_with_includes_sync_status import SyncGroupWithIncludesSyncStatus


class SyncGroupWithIncludes(GroupCommonWithIncludes):
    sync_status: SyncGroupWithIncludesSyncStatus = pydantic.Field()
    """
    Imported group sync status
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel


class Anchor(UniversalBaseModel):
    x: float = pydantic.Field()
    """
    Horizontal comment anchor location.
    """

    y: float = pydantic.Field()
    """
    Vertical comment anchor location.
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel
from .transcription_match_matches_item import TranscriptionMatchMatchesItem


class TranscriptionMatch(UniversalBaseModel):
    """
    The result's transcription is a match for the search query
    """

    matches: typing.List[TranscriptionMatchMatchesItem] = pydantic.Field()
    """
    The transcriptions that match
    """

    type: typing.Literal["transcription_match"] = "transcription_match"

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.group_response import GroupResponse
from ..types.group_with_includes_response import GroupWithIncludesResponse
from ..types.groups_with_includes_response import GroupsWithIncludesResponse
from ..types.include_total_count import IncludeTotalCount
from ..types.request_after_opaque_cursor import RequestAfterOpaqueCursor
from ..types.request_page_size import RequestPageSize
from ..types.uuid_ import Uuid
from .raw_client import AsyncRawGroupsClient, RawGroupsClient
from .types.create_group_params_data import CreateGroupParamsData
from .types.groups_index_request_sort import GroupsIndexRequestSort
from .types.update_group_params_data import UpdateGroupParamsData

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class GroupsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawGroupsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawGroupsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawGroupsClient
        """
        return self._raw_client

    def index(
        self,
        account_id: Uuid,
        *,
        include: typing.Optional[typing.Literal["creator"]] = None,
        sort: typing.Optional[GroupsIndexRequestSort] = None,
        after: typing.Optional[RequestAfterOpaqueCursor] = None,
        page_size: typing.Optional[RequestPageSize] = None,
        include_total_count: typing.Optional[IncludeTotalCount] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GroupsWithIncludesResponse:
        """
        List groups in account. <br/>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        include : typing.Optional[typing.Literal["creator"]]


        sort : typing.Optional[GroupsIndexRequestSort]
            Sort groups by query params

        after : typing.Optional[RequestAfterOpaqueCursor]
            Opaque Cursor query param for requests returning paginated results.
            <br/>
            NOTE: this value is auto-generated and included as part of links from a previous response. It is not intended to be human readable.

        page_size : typing.Optional[RequestPageSize]


        include_total_count : typing.Optional[IncludeTotalCount]


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GroupsWithIncludesResponse
            OK

        Examples
        --------
        from frameio_experimental import FrameioExperimental

        client = FrameioExperimental(
            api_version="YOUR_API_VERSION",
            token="YOUR_TOKEN",
        )
        client.groups.index(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            sort="creator_asc",
            after="<opaque_cursor>",
            page_size=10,
            include_total_count=False,
        )
        """
        _response = self._raw_client.index(
            account_id,
            include=include,
            sort=sort,
            after=after,
            page_size=page_size,
            include_total_count=include_total_count,
            request_options=request_options,
        )
        return _response.data

    def create(
        self, account_id: Uuid, *, data: CreateGroupParamsData, request_options: typing.Optional[RequestOptions] = None
    ) -> GroupResponse:
        """
        Create group for the current account. <br/>Rate Limits: 10 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        data : CreateGroupParamsData

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GroupResponse
            Created

        Examples
        --------
        from frameio_experimental import FrameioExperimental
        from frameio_experimental.groups import CreateGroupParamsData

        client = FrameioExperimental(
            api_version="YOUR_API_VERSION",
            token="YOUR_TOKEN",
        )
        client.groups.create(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            data=CreateGroupParamsData(
                emoji="smile",
                name="group-1",
            ),
        )
        """
        _response = self._raw_client.create(account_id, data=data, request_options=request_options)
        return _response.data

    def show(
        self,
        account_id: Uuid,
        group_id: Uuid,
        *,
        include: typing.Optional[typing.Literal["creator"]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GroupWithIncludesResponse:
        """
        Show group details. <br>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        group_id : Uuid


        include : typing.Optional[typing.Literal["creator"]]


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GroupWithIncludesResponse
            OK

        Examples
        --------
        from frameio_experimental import FrameioExperimental

        client = FrameioExperimental(
            api_version="YOUR_API_VERSION",
            token="YOUR_TOKEN",
        )
        client.groups.show(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            group_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
        )
        """
        _response = self._raw_client.show(account_id, group_id, include=include, request_options=request_options)
        return _response.data

    def update(
        self,
        account_id: Uuid,
        group_id: Uuid,
        *,
        data: UpdateGroupParamsData,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GroupResponse:
        """
        Update group details. <br/>Rate Limits: 10 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        group_id : Uuid


        data : UpdateGroupParamsData

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GroupResponse
            OK

        Examples
        --------
        from frameio_experimental import FrameioExperimental
        from frameio_experimental.groups import UpdateGroupParamsData

        client = FrameioExperimental(
            api_version="YOUR_API_VERSION",
            token="YOUR_TOKEN",
        )
        client.groups.update(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            group_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            data=UpdateGroupParamsData(
                emoji="smile",
                name="group-1",
            ),
        )
        """
        _response = self._raw_client.update(account_id, group_id, data=data, request_options=request_options)
        return _response.data


class AsyncGroupsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawGroupsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawGroupsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawGroupsClient
        """
        return self._raw_client

    async def index(
        self,
        account_id: Uuid,
        *,
        include: typing.Optional[typing.Literal["creator"]] = None,
        sort: typing.Optional[GroupsIndexRequestSort] = None,
        after: typing.Optional[RequestAfterOpaqueCursor] = None,
        page_size: typing.Optional[RequestPageSize] = None,
        include_total_count: typing.Optional[IncludeTotalCount] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GroupsWithIncludesResponse:
        """
        List groups in account. <br/>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        include : typing.Optional[typing.Literal["creator"]]


        sort : typing.Optional[GroupsIndexRequestSort]
            Sort groups by query params

        after : typing.Optional[RequestAfterOpaqueCursor]
            Opaque Cursor query param for requests returning paginated results.
            <br/>
            NOTE: this value is auto-generated and included as part of links from a previous response. It is not intended to be human readable.

        page_size : typing.Optional[RequestPageSize]


        include_total_count : typing.Optional[IncludeTotalCount]


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GroupsWithIncludesResponse
            OK

        Examples
        --------
        import asyncio

        from frameio_experimental import AsyncFrameioExperimental

        client = AsyncFrameioExperimental(
            api_version="YOUR_API_VERSION",
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.groups.index(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                sort="creator_asc",
                after="<opaque_cursor>",
                page_size=10,
                include_total_count=False,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.index(
            account_id,
            include=include,
            sort=sort,
            after=after,
            page_size=page_size,
            include_total_count=include_total_count,
            request_options=request_options,
        )
        return _response.data

    async def create(
        self, account_id: Uuid, *, data: CreateGroupParamsData, request_options: typing.Optional[RequestOptions] = None
    ) -> GroupResponse:
        """
        Create group for the current account. <br/>Rate Limits: 10 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        data : CreateGroupParamsData

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GroupResponse
            Created

        Examples
        --------
        import asyncio

        from frameio_experimental import AsyncFrameioExperimental
        from frameio_experimental.groups import CreateGroupParamsData

        client = AsyncFrameioExperimental(
            api_version="YOUR_API_VERSION",
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.groups.create(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                data=CreateGroupParamsData(
                    emoji="smile",
                    name="group-1",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create(account_id, data=data, request_options=request_options)
        return _response.data

    async def show(
        self,
        account_id: Uuid,
        group_id: Uuid,
        *,
        include: typing.Optional[typing.Literal["creator"]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GroupWithIncludesResponse:
        """
        Show group details. <br>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        group_id : Uuid


        include : typing.Optional[typing.Literal["creator"]]


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GroupWithIncludesResponse
            OK

        Examples
        --------
        import asyncio

        from frameio_experimental import AsyncFrameioExperimental

        client = AsyncFrameioExperimental(
            api_version="YOUR_API_VERSION",
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.groups.show(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                group_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.show(account_id, group_id, include=include, request_options=request_options)
        return _response.data

    async def update(
        self,
        account_id: Uuid,
        group_id: Uuid,
        *,
        data: UpdateGroupParamsData,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GroupResponse:
        """
        Update group details. <br/>Rate Limits: 10 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        group_id : Uuid


        data : UpdateGroupParamsData

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GroupResponse
            OK

        Examples
        --------
        import asyncio

        from frameio_experimental import AsyncFrameioExperimental
        from frameio_experimental.groups import UpdateGroupParamsData

        client = AsyncFrameioExperimental(
            api_version="YOUR_API_VERSION",
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.groups.update(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                group_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                data=UpdateGroupParamsData(
                    emoji="smile",
                    name="group-1",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.update(account_id, group_id, data=data, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel
from .links import Links
from .search_response_data_item import SearchResponseDataItem


class SearchResponse(UniversalBaseModel):
    """
    Response containing search results
    """

    data: typing.List[SearchResponseDataItem] = pydantic.Field()
    """
    List of search results
    """

    links: Links
    total_count: typing.Optional[int] = pydantic.Field(default=None)
    """
    Total number of matching results
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel


class TextReviewAnnotationBounds(UniversalBaseModel):
    height: float = pydantic.Field()
    """
    Height of the rectangle
    """

    width: float = pydantic.Field()
    """
    Width of the rectangle
    """

    x: float = pydantic.Field()
    """
    Left corner position.
    """

    y: float = pydantic.Field()
    """
    Bottom corner position.
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
